@@ -15,9 +15,9 @@ class FlaskAuthentication(Authentication):
         flask.request.form = context.data
         return context
 
-    def from_first_request(self):
+    def from_first_request(self, type=None):
         raw_data = flask.request.data
         data = self.session_handler.decode_data(raw_data)
-        context = self.get_first_context(data)
+        context = self.get_first_context(data, type)
         flask.request.form = context.data
         return context
